import json

from tornado.web import RequestHandler

from agent.domain import DOMAINOBJ, DOMAINMSG
from agent.common.pylog import logger


class RollbackHandler(RequestHandler):
    def post(self):
        request_data = json.loads(self.request.body)
        logger.debug("[Request] Get rollback request:{}".format(request_data))
        domain_list   = request_data['domains']

        domain_result = {}
        # Rollback all domain to initial state
        if request_data['all']:
            logger.debug("[Request] field 'all' is 'True', rollback all domains")
            for domain_name in DOMAINOBJ.keys():
                suc, res = DOMAINOBJ[domain_name].Rollback(all = True)
                domain_result[domain_name] = {
                    "suc": suc,
                    "msg": res,
                }
        
        # Rollback all domain to latest state
        elif domain_list.__len__() == 0:
            logger.debug("[Request] field 'domains' is empty, try to rollback all domains")
            for domain_name in DOMAINOBJ.keys():
                suc, res = DOMAINOBJ[domain_name].Rollback(all = False)
                domain_result[domain_name] = {
                    "suc": suc,
                    "msg": res,
                }
        
        # Rollback selected domain to latest state
        else:
            logger.debug("[Request] rollback domains as list:{}".format(domain_list))
            for domain_name in domain_list:
                if not DOMAINOBJ.__contains__(domain_name) and DOMAINMSG.__contains__(domain_name):
                    domain_result[domain_name] = {
                        "suc": False,
                        "msg": "inactive domain '{}':{}".format(domain_name, DOMAINMSG[domain_name])
                    }

                elif not DOMAINOBJ.__contains__(domain_name):
                    domain_result[domain_name] = {
                        "suc": False,
                        "msg": "undefined domain '{}'".format(domain_name)
                    }
                    
                else:
                    suc, res = DOMAINOBJ[domain_name].Rollback(all=False)
                    domain_result[domain_name] = {
                        "suc": suc,
                        "msg": res
                    }

        logger.debug("[Request] rollback request result:{}".format(domain_result))
        self.write(json.dumps(domain_result))
        self.finish()