import os
import re  

from importlib import import_module
from collections import defaultdict  

from agent.common.pylog import logger
from agent.domain.base import BaseDomain

DOMAINOBJ = {}
DOMAINMSG = {}

def initDomain():
    from agent import domain
    
    domain_dir = os.path.split(__file__)[0]
    domain_list = [re.sub('.py','',p) 
                   for p in os.listdir(domain_dir) 
                   if p.endswith('.py') and not p.startswith('_') and not p.startswith('base')]
    
    logger.info("find {} domain files in {}".format(len(domain_list), domain_dir))
    for domain_name in domain_list:
        class_name = "".join([value.capitalize() for value in domain_name.split("_")]) if "_" in domain_name else domain_name.capitalize()
        
        try:
            import_module('agent.domain.{}'.format(domain_name))
            domain_obj = eval('domain.{domain_name}.{class_name}()'.format(
                domain_name = domain_name,
                class_name = class_name
            ))
            if isinstance(domain_obj,BaseDomain):
                DOMAINOBJ[domain_name] = domain_obj
                DOMAINMSG[domain_name] = "ready"
                
        except Exception as e:
            logger.warning("[-] Load domain {domain_name}.{class_name} failed: {message}".format(
                domain_name = domain_name, 
                class_name = class_name,
                message = e))
            DOMAINMSG[domain_name] = "{}".format(e)

    for domain_name, msg in DOMAINMSG.items():
        print("[DOMAIN] {} : {} ".format(domain_name,msg))